ngff_zarr.task_count - ngff-zarr
Description: Module Contents: Functions:,, task_count, Approximate dask array partition task count.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.task_count`

## Module Contents

### Functions

`task_count` | Approximate dask array partition task count.

### API

ngff_zarr.task_count.task_count(image: ngff_zarr.ngff_image.NgffImage, constrained_dims: Optional[Set[str]] = None) → int

  Approximate dask array partition task count.